#!/bin/bash
# +------------------------------------------------------------------+
# |          _           _           _       _   __   _______        |
# |       __| |_  ___ __| |__  _ __ | |__   / | /  \ |__ / __|       |
# |      / _| ' \/ -_) _| / / | '  \| / /   | || () | |_ \__ \       |
# |      \__|_||_\___\__|_\_\_|_|_|_|_\_\   |_(_)__(_)___/___/       |
# |                                            check_mk 1.0.35       |
# |                                                                  |
# | Copyright Mathias Kettner 2009                mk@mathias-kettner |
# +------------------------------------------------------------------+
# 
# This file is part of check_mk 1.0.35.
# The official homepage is at http://mathias-kettner.de/check_mk.
# 
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# ails.  You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

TEMPLATEDIR=${1:-/etc/nagios/logwatch}
STATUSDIR=${2:-/var/lib/nagios/logwatch/seek}

usage ()
{
cat <<EOF
   Usage: mk_logwatch [ TEMPLATEDIR [STATUSDIR] ]
EOF
   exit 1
}


if [ ! -d "$TEMPLATEDIR" ] ; then echo "No such directory: $TEMPLATEDIR" ; usage ; fi
if [ ! -d "$STATUSDIR" ] ; then echo "No such directory: $STATUSDIR" ; usage ; fi




mkdir -p $STATUSDIR

check_logfile ()
{
    file=$1
    keywords=$2

    INODE=$(ls -i "$file" 2>/dev/null | cut -d' ' -f1)
    if [ -z "$INODE" ] ; then
	echo "[[[$file:missing]]]"
        return
    fi

    echo "[[[$file]]]"

    # Seekfile? => start grep from previously scanned position,
    # but only if inode number has not changed
    SEEKFILE=$STATUSDIR/${file//\//\\} 
    if [ -e "$SEEKFILE" ] && read pos inode < $SEEKFILE && [ -n "$INODE" -a "$inode" = "$INODE" ] 
    then
	dd_options="bs=$pos skip=1"
    else
	dd_options=""
    fi
    ENDPOS=$(wc --bytes < $file)

    # Seek to position with dd
    dd if=$file $dd_options 2>/dev/null | grep -f <(sed -e 1d -e '/^[[:space:]]*#/d' < $keywords)
    echo "$ENDPOS $INODE" > $SEEKFILE
}


echo '<<<logwatch>>>'
# Suche alle Logdateien, die in den Schablonen aufgefuehrt sind
for template in $TEMPLATEDIR/*.keywords
do
    LOGFILEPATTERN=$(head -n1 $template)
    for logfile in $LOGFILEPATTERN
    do
        check_logfile "$logfile" "$template"
    done
done
